@@ -1,7 +1,7 @@
 package Module::XSOrPP;
 
-our $DATE = '2015-04-21'; # DATE
-our $VERSION = '0.08'; # VERSION
+our $DATE = '2015-05-22'; # DATE
+our $VERSION = '0.09'; # VERSION
 
 use 5.010001;
 use strict;
@@ -23,6 +23,13 @@ our @XS_OR_PP_MODULES = qw(
                               List::MoreUtils
 );
 
+our @XS_MODULES = qw(
+                        Scalar::Util
+                );
+
+our @PP_MODULES = qw(
+                );
+
 sub xs_or_pp {
     use experimental 'smartmatch';
 
@@ -41,9 +48,20 @@ sub xs_or_pp {
     my $debug = $opts->{debug};
 
     if ($mod ~~ @XS_OR_PP_MODULES) {
+        warn "$mod is xs_or_pp (from list)\n" if $debug;
         return "xs_or_pp";
     }
 
+    if ($mod ~~ @XS_MODULES) {
+        warn "$mod is xs (from list)\n" if $debug;
+        return "xs";
+    }
+
+    if ($mod ~~ @PP_MODULES) {
+        warn "$mod is pp (from list)\n" if $debug;
+        return "pp";
+    }
+
     my $path = packlist_for($mod);
     {
         last unless $path;
@@ -128,7 +146,7 @@ Module::XSOrPP - Determine if an installed module is XS or pure-perl
 
 =head1 VERSION
 
-This document describes version 0.08 of Module::XSOrPP (from Perl distribution Module-XSOrPP), released on 2015-04-21.
+This document describes version 0.09 of Module::XSOrPP (from Perl distribution Module-XSOrPP), released on 2015-05-22.
 
 =head1 SYNOPSIS
 
